darkhistory.low_energy.lowE_electrons.make_interpolator — DarkHistory documentation

# darkhistory.low_energy.lowE_electrons.make_interpolator

`darkhistory.low_energy.lowE_electrons.` `make_interpolator`(interp_type='2D')

  Creates cubic splines that interpolate the Medea Data. Stores them in globally defined variables so that these functions are only computed once

  Assumes that the data files are in the same directory as this script.

  Parameters: | interp_type : {‘1D’, ‘2D’}, optional Returns the type of interpolation over the MEDEA data.
  Returns: | Interpolator2D or function The interpolating function (takes x_e and electron energy)

#### Previous topic

darkhistory.low_energy.lowE_electrons.compute_fs

#### Next topic

darkhistory.low_energy.lowE_photons

### This Page

Show Source